def to_uppercase(text: str) -> str:
    """
    Converts a string to uppercase.
    :param text: The input string.
    :return: Uppercase version of the string.
    """
    if not isinstance(text, str):
        raise ValueError("Input must be a string")
    return text.upper()


from setuptools import setup, find_packages

setup(
    name='neszen-package',
    version='0.1.0',
    description='A simple package to convert text to uppercase',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    packages=find_packages(),
    python_requires='>=3.6',
    install_requires=[

    ], 
)